@@ -212,29 +212,40 @@ bool CVRPathRegistry_Public::ToJsonString( std::string &sJsonString )
 // ---------------------------------------------------------------------------
 // Purpose: Loads the config file from its well known location
 // ---------------------------------------------------------------------------
-bool CVRPathRegistry_Public::BLoadFromFile()
+bool CVRPathRegistry_Public::BLoadFromFile( std::string *psLoadError )
 {
 	std::string sRegPath = GetVRPathRegistryFilename();
 	if( sRegPath.empty() )
 	{
-		VRLog( "Unable to determine VR Path Registry filename\n" );
+		if ( psLoadError )
+		{
+			*psLoadError = "Unable to determine VR Path Registry filename";
+		}
 		return false;
 	}
 
 	std::string sRegistryContents = Path_ReadTextFile( sRegPath );
 	if( sRegistryContents.empty() )
 	{
-		VRLog( "Unable to read VR Path Registry from %s\n", sRegPath.c_str() );
+		if ( psLoadError )
+		{
+			*psLoadError = "Unable to read VR Path Registry from " + sRegPath;
+		}
 		return false;
 	}
 
 	Json::Value root;
-	Json::Reader reader;
+	Json::CharReaderBuilder builder;
+	std::istringstream istream( sRegistryContents );
+	std::string sErrors;
 
 	try {
-		if ( !reader.parse( sRegistryContents, root ) )
+		if ( !parseFromStream( builder, istream, &root, &sErrors ) )
 		{
-			VRLog( "Unable to parse %s: %s\n", sRegPath.c_str(), reader.getFormattedErrorMessages().c_str() );
+			if ( psLoadError )
+			{
+				*psLoadError = "Unable to parse " + sRegPath + ": " + sErrors;
+			}
 			return false;
 		}
 
@@ -248,7 +259,10 @@ bool CVRPathRegistry_Public::BLoadFromFile()
 	}
 	catch ( ... )
 	{
-		VRLog( "Unable to parse %s: %s\n", sRegPath.c_str(), "exception thrown in JSON library" );
+		if ( psLoadError )
+		{
+			*psLoadError = "Unable to parse " + sRegPath + ": exception thrown in JSON library";
+		}
 		return false;
 	}
 
@@ -261,9 +275,6 @@ bool CVRPathRegistry_Public::BLoadFromFile()
 // ---------------------------------------------------------------------------
 bool CVRPathRegistry_Public::BSaveToFile() const
 {
-#if defined( DASHBOARD_BUILD_MODE )
-	return false;
-#else
 	std::string sRegPath = GetVRPathRegistryFilename();
 	if( sRegPath.empty() )
 		return false;
@@ -278,8 +289,8 @@ bool CVRPathRegistry_Public::BSaveToFile() const
 	StringListToJson( m_vecLogPath, root, "log" );
 	StringListToJson( m_vecExternalDrivers, root, "external_drivers" );
 
-	Json::StyledWriter writer;
-	std::string sRegistryContents = writer.write( root );
+	Json::StreamWriterBuilder builder;
+	std::string sRegistryContents = Json::writeString( builder, root );
 
 	// make sure the directory we're writing into actually exists
 	std::string sRegDirectory = Path_StripFilename( sRegPath );
@@ -296,7 +307,6 @@ bool CVRPathRegistry_Public::BSaveToFile() const
 	}
 
 	return true;
-#endif
 }
 
 
@@ -343,12 +353,15 @@ std::string CVRPathRegistry_Public::GetLogPath() const
 // ---------------------------------------------------------------------------
 bool CVRPathRegistry_Public::GetPaths( std::string *psRuntimePath, std::string *psConfigPath, std::string *psLogPath, const char *pchConfigPathOverride, const char *pchLogPathOverride, std::vector<std::string> *pvecExternalDrivers )
 {
+	std::string sLoadError;
 	CVRPathRegistry_Public pathReg;
-	bool bLoadedRegistry = pathReg.BLoadFromFile();
+	bool bLoadedRegistry = pathReg.BLoadFromFile( &sLoadError );
 	int nCountEnvironmentVariables = 0;
+	int nRequestedPaths = 0;
 
 	if( psRuntimePath )
 	{
+		nRequestedPaths++;
 		if ( GetEnvironmentVariable( k_pchRuntimeOverrideVar ).length() != 0 )
 		{
 			*psRuntimePath = GetEnvironmentVariable( k_pchRuntimeOverrideVar );
@@ -366,6 +379,7 @@ bool CVRPathRegistry_Public::GetPaths( std::string *psRuntimePath, std::string *
 
 	if( psConfigPath )
 	{
+		nRequestedPaths++;
 		if ( GetEnvironmentVariable( k_pchConfigOverrideVar ).length() != 0 )
 		{
 			*psConfigPath = GetEnvironmentVariable( k_pchConfigOverrideVar );
@@ -387,6 +401,7 @@ bool CVRPathRegistry_Public::GetPaths( std::string *psRuntimePath, std::string *
 
 	if( psLogPath )
 	{
+		nRequestedPaths++;
 		if ( GetEnvironmentVariable( k_pchLogOverrideVar ).length() != 0 )
 		{
 			*psLogPath = GetEnvironmentVariable( k_pchLogOverrideVar );
@@ -411,11 +426,15 @@ bool CVRPathRegistry_Public::GetPaths( std::string *psRuntimePath, std::string *
 		*pvecExternalDrivers = pathReg.m_vecExternalDrivers;
 	}
 
-	if ( nCountEnvironmentVariables == 3 )
+	if ( nCountEnvironmentVariables == nRequestedPaths )
 	{
 		// all three environment variables were set, so we don't need the physical file
 		return true;
 	}
+	else if( !bLoadedRegistry )
+	{
+		VRLog( "%s\n", sLoadError.c_str() );
+	}
 
 	return bLoadedRegistry;
 }
